==> luna3-2.13.41.tar.gz: luna3-2.13.41/luna3/common/luna_request.py <==
"""
Module implements http request.
"""

from typing import Any, Dict, Iterator, Mapping, Optional, Union

import aiohttp
import filetype
from yarl import URL


def prepareQueryParams(queryParams: Optional[dict] = None) -> Union[None, Dict[str, str]]:
    """
    The function generates a dict with query parameters, acceptable for a asyncio request.

    Args:
        queryParams: dictionary with parameters

    Returns:
        another dictionary with query parameters

    >>> prepareQueryParams({"warped_image": 1, "estimate_attributes": False})
    {"warped_image": "1", "estimate_attributes": "0"}

    >>> prepareQueryParams({"warped_image": 1, "parts": [0,1,2,5]})
    {"warped_image": "1", "parts": "0,1,2,5"}

    >>> prepareQueryParams({"user_data": "new data"})
    {"user_data": "new data"}
    """
    if queryParams is None:
        return None

    newQueries = {}
    for name, value in queryParams.items():
        if value is None:
            continue
        if isinstance(value, (list, tuple, set)):
            newQueries[name] = ",".join(str(p) for p in value)
        elif isinstance(value, bool):
            newQueries[name] = str(int(value))
        else:
            newQueries[name] = str(value)
    return newQueries


def guessContentType(body: bytes) -> str:
    """
    The function that try to get content type.
    Args:
        body: body bytes

    Returns:
        Content-Type
    Raises:
        ValueError: if it is not possible to find out Content-Type
    """
    contentType = filetype.guess(body)
    if contentType is not None:
        if contentType.mime in ("image/jpeg", "image/png", "image/gif", "image/bmp", "image/tiff"):
            return contentType.mime
    if body[:4] == b"XPKF":
        return "application/x-vl-xpk"
    if body[:4] == b"dp\x00\x00":
        return "application/x-sdk-descriptor"
    if body[:2] in (b"P6", b"P3"):
        return "image/x-portable-pixmap"
    raise ValueError(
        "wrong mimetype, availbale mimetypes are: image/jpeg, image/png, image/gif, image/bmp, "
        "image/tiff, application/x-vl-xpk, application/x-sdk-descriptor"
    )


class LunaRequest(Mapping[str, Any]):
    """
    LunaRequest stores aiohttp.ClientSession.request data.

    Mapping class allows using objects as mapping (** operator)

    !DEVELOPERS!
    You can add more __slots__ from the following request args:
        https://docs.aiohttp.org/en/latest/client_reference.html#aiohttp.ClientSession.request

    Attributes:
        url (URL): request url
        method (str): request method
        data (Optional[Any]): request data
        json (Optional[Union[dict, list, int, str, float]]): request json
        params (Optional[Dict[str, str]]): request params
        headers (Dict[str, str]): request headers
        timeout (Optional[aiohttp.ClientTimeout]): request timeout

    >>> import asyncio
    ... async def example():
    ...     req = LunaRequest('http://wttr.in', 'GET')
    ...     async with aiohttp.ClientSession() as session:
    ...         async with aiohttp.request(**req) as reply:
    ...             print(reply.status)
    ...             # print(await reply.text())
    ... asyncio.run(example())
    200
    """

    __slots__ = ("url", "method", "data", "json", "params", "headers", "timeout")

    def __init__(
        self,
        url: str,
        method: str,
        *,
        body: Optional[Any] = None,
        json: Optional[Union[dict, list, int, str, float]] = None,
        params: Optional[Dict[str, str]] = None,
        headers: Optional[Dict[str, str]] = None,
        timeout: Optional[aiohttp.ClientTimeout] = None,
    ):
        self.url: URL = URL(url, encoded=True)
        self.method: str = method
        self.data: Optional[Any] = body
        self.json: Optional[Union[dict, list, int, str, float]] = json
        self.params: Optional[Dict[str, str]] = prepareQueryParams(params)
        self.headers: Dict[str, str] = headers if headers is not None else {}
        self.timeout: Optional[aiohttp.ClientTimeout] = timeout

    # Mapping realisation starts
    def __len__(self) -> int:
        """
        Returns:
            count of not-None attributes
        """
        return len(list(self.__iter__()))

    def __iter__(self) -> Iterator[str]:
        """
        Returns:
            not-None attributes' names
        """
        for slotName in self.__slots__:
            if self[slotName] is not None:
                yield slotName

    def __getitem__(self, name: str) -> Any:
        """
        Returns:
            attribute value by attribute name
        """
        return self.__getattribute__(name)

    # Mapping realisation ends

    def __repr__(self) -> str:
        """
        Returns:
            instance string representation
        """
        return f"<{self.__class__.__name__}> {self.method}:{self.url}"

==> luna3-2.13.60.tar.gz: luna3-2.13.60/luna3/common/luna_request.py <==
"""
Module implements http request.
"""
from ssl import SSLContext
from typing import Any, Dict, Iterator, Mapping, Optional, Union

import aiohttp
import filetype
from yarl import URL


def prepareQueryParams(queryParams: Optional[dict] = None) -> Union[None, Dict[str, str]]:
    """
    The function generates a dict with query parameters, acceptable for a asyncio request.

    Args:
        queryParams: dictionary with parameters

    Returns:
        another dictionary with query parameters

    >>> prepareQueryParams({"warped_image": 1, "estimate_attributes": False})
    {"warped_image": "1", "estimate_attributes": "0"}

    >>> prepareQueryParams({"warped_image": 1, "parts": [0,1,2,5]})
    {"warped_image": "1", "parts": "0,1,2,5"}

    >>> prepareQueryParams({"user_data": "new data"})
    {"user_data": "new data"}
    """
    if queryParams is None:
        return None

    newQueries = {}
    for name, value in queryParams.items():
        if value is None:
            continue
        if isinstance(value, (list, tuple, set)):
            newQueries[name] = ",".join(str(p) for p in value)
        elif isinstance(value, bool):
            newQueries[name] = str(int(value))
        else:
            newQueries[name] = str(value)
    return newQueries


def guessContentType(body: bytes) -> str:
    """
    The function that try to get content type.
    Args:
        body: body bytes

    Returns:
        Content-Type
    Raises:
        ValueError: if it is not possible to find out Content-Type
    """
    contentType = filetype.guess(body)
    if contentType is not None:
        if contentType.mime in ("image/jpeg", "image/png", "image/gif", "image/bmp", "image/tiff"):
            return contentType.mime
    if body[:4] == b"XPKF":
        return "application/x-vl-xpk"
    if body[:4] == b"dp\x00\x00":
        return "application/x-sdk-descriptor"
    if body[:2] in (b"P6", b"P3"):
        return "image/x-portable-pixmap"
    raise ValueError(
        "wrong mimetype, availbale mimetypes are: image/jpeg, image/png, image/gif, image/bmp, "
        "image/tiff, application/x-vl-xpk, application/x-sdk-descriptor"
    )


class LunaRequest(Mapping[str, Any]):
    """
    LunaRequest stores aiohttp.ClientSession.request data.

    Mapping class allows using objects as mapping (** operator)

    !DEVELOPERS!
    You can add more __slots__ from the following request args:
        https://docs.aiohttp.org/en/latest/client_reference.html#aiohttp.ClientSession.request

    Attributes:
        url (URL): request url
        method (str): request method
        data (Optional[Any]): request data
        json (Optional[Union[dict, list, int, str, float]]): request json
        params (Optional[Dict[str, str]]): request params
        headers (Dict[str, str]): request headers
        timeout (Optional[aiohttp.ClientTimeout]): request timeout
        ssl (Optional[SSLContext]): ssl context

    >>> import asyncio
    ... async def example():
    ...     req = LunaRequest('http://wttr.in', 'GET')
    ...     async with aiohttp.ClientSession() as session:
    ...         async with aiohttp.request(**req) as reply:
    ...             print(reply.status)
    ...             # print(await reply.text())
    ... asyncio.run(example())
    200
    """

    __slots__ = ("url", "method", "data", "json", "params", "headers", "timeout", "ssl")

    def __init__(
        self,
        url: str,
        method: str,
        *,
        body: Optional[Any] = None,
        json: Optional[Union[dict, list, int, str, float]] = None,
        params: Optional[Dict[str, str]] = None,
        headers: Optional[Dict[str, str]] = None,
        timeout: Optional[aiohttp.ClientTimeout] = None,
        ssl: Optional[SSLContext] = None,
    ):
        self.url: URL = URL(url, encoded=True)
        self.method: str = method
        self.data: Optional[Any] = body
        self.json: Optional[Union[dict, list, int, str, float]] = json
        self.params: Optional[Dict[str, str]] = prepareQueryParams(params)
        self.headers: Dict[str, str] = headers if headers is not None else {}
        self.timeout: Optional[aiohttp.ClientTimeout] = timeout
        self.ssl = ssl

    # Mapping realisation starts
    def __len__(self) -> int:
        """
        Returns:
            count of not-None attributes
        """
        return len(list(self.__iter__()))

    def __iter__(self) -> Iterator[str]:
        """
        Returns:
            not-None attributes' names
        """
        for slotName in self.__slots__:
            if self[slotName] is not None:
                yield slotName

    def __getitem__(self, name: str) -> Any:
        """
        Returns:
            attribute value by attribute name
        """
        return self.__getattribute__(name)

    # Mapping realisation ends

    def __repr__(self) -> str:
        """
        Returns:
            instance string representation
        """
        return f"<{self.__class__.__name__}> {self.method}:{self.url}"
